@@ -82,18 +82,20 @@ class Document(Validations):
         return tables
 
     def to_xlsx(self, dest: Union[str, Path, io.BytesIO], ocr: "OCRInstance" = None, implicit_rows: bool = True,
-                min_confidence: int = 50) -> Optional[io.BytesIO]:
+                borderless_tables: bool = False, min_confidence: int = 50) -> Optional[io.BytesIO]:
         """
         Create xlsx file containing all extracted tables from document
         :param dest: destination for xlsx file
         :param ocr: OCRInstance object used to extract table content
         :param implicit_rows: boolean indicating if implicit rows are splitted
+        :param borderless_tables: boolean indicating if borderless tables should be detected
         :param min_confidence: minimum confidence level from OCR in order to process text, from 0 (worst) to 99 (best)
         :return: if a buffer is passed as dest arg, it is returned containing xlsx data
         """
         # Extract tables
         extracted_tables = self.extract_tables(ocr=ocr,
                                                implicit_rows=implicit_rows,
+                                               borderless_tables=borderless_tables,
                                                min_confidence=min_confidence)
         extracted_tables = {0: extracted_tables} if isinstance(extracted_tables, list) else extracted_tables
 
